==> nextcloud-app-spreed-1%3A11.3.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/en_GB.js <==
OC.L10N.register(
    "spreed",
    {
    "a conversation" : "a conversation",
    "(Duration %s)" : "(Duration %s)",
    "You attended a call with {user1}" : "You attended a call with {user1}",
    "_%n guest_::_%n guests_" : ["%n guest","%n guests"],
    "You attended a call with {user1} and {user2}" : "You attended a call with {user1} and {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "You attended a call with {user1}, {user2} and {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "You attended a call with {user1}, {user2}, {user3} and {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}",
    "_%n other_::_%n others_" : ["%n other","%n others"],
    "{actor} invited you to {call}" : "{actor} invited you to {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>",
    "Talk" : "Talk",
    "Guest" : "Guest",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk.",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge and Safari can now be used to participate in audio and video calls",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- You can now notify all participants by posting \"@all\" into the chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- With the \"arrow-up\" key you can repost your last message",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some",
    "- With projects you can create quick links between conversations, files and other items" : "- With projects you can create quick links between conversations, files and other items",
    "- You can now mention guests in the chat" : "- You can now mention guests in the chat",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- You can now directly reply to messages giving the other users more context what your message is about",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- You can now add custom user groups to conversations when the circles app is installed",
    "- Check out the new grid and call view" : "- Check out the new grid and call view",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- You can now upload and drag'n'drop files directly from your device into the chat",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Shared files are now opened directly inside the chat view with the viewer apps",
    "- You can now search for chats and messages in the unified search in the top bar" : "- You can now search for chats and messages in the unified search in the top bar",
    "- Spice up your messages with emojis from the emoji picker" : "- Spice up your messages with emojis from the emoji picker",
    "- You can now change your camera and microphone while being in a call" : "- You can now change your camera and microphone while being in a call",
    "There are currently no commands available." : "There are currently no commands available.",
    "The command does not exist" : "The command does not exist",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "An error occurred while running the command. Please ask an administrator to check the logs.",
    "Talk updates ✅" : "Talk updates ✅",
    "{actor} created the conversation" : "{actor} created the conversation",
    "You created the conversation" : "You created the conversation",
    "An administrator created the conversation" : "An administrator created the conversation",
    "Talk to %s" : "Talk to %s",
    "{user} mentioned you in a private conversation" : "{user} mentioned you in a private conversation",
    "{user} invited you to a private conversation" : "{user} invited you to a private conversation",
    "Join call" : "Join call",
    "{user} invited you to a group conversation: {call}" : "{user} invited you to a group conversation: {call}",
    "A group call has started in {call}" : "A group call has started in {call}",
    "Open settings" : "Open settings",
    "Conversations" : "Conversations",
    "Messages" : "Messages",
    "Invalid date, date format must be YYYY-MM-DD" : "Invalid date, date format must be YYYY-MM-DD",
    "Leave call" : "Leave call",
    "This conversation has ended" : "This conversation has ended",
    "Limit to groups" : "Limit to groups",
    "Everyone" : "Everyone",
    "Save changes" : "Save changes",
    "Saved!" : "Saved!",
    "None" : "None",
    "User" : "User",
    "Disabled" : "Disabled",
    "Users" : "Users",
    "Beta" : "Beta",
    "Name" : "Name",
    "General settings" : "General settings",
    "Off" : "Off",
    "Language" : "Language",
    "Country" : "Country",
    "Status" : "Status",
    "Created at" : "Created at",
    "Pending" : "Pending",
    "Error" : "Error",
    "Blocked" : "Blocked",
    "Expired" : "Expired",
    "Shared secret" : "Shared secret",
    "Validate SSL certificate" : "Validate SSL certificate",
    "Saved" : "Saved",
    "STUN servers" : "STUN servers",
    "A STUN server is used to determine the public IP address of participants behind a router." : "A STUN server is used to determine the public IP address of participants behind a router.",
    "TURN server protocols" : "TURN server protocols",
    "Copy link" : "Copy link",
    "Waiting for others to join the call …" : "Waiting for others to join the call …",
    "You can invite others in the participant tab of the sidebar" : "You can invite others in the participant tab of the sidebar",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "You can invite others in the participant tab of the sidebar or share this link to invite others!",
    "Share this link to invite others!" : "Share this link to invite others!",
    "Show your screen" : "Show your screen",
    "Stop screensharing" : "Stop screensharing",
    "Settings" : "Settings",
    "Dismiss" : "Dismiss",
    "No audio" : "No audio",
    "Mute audio" : "Mute audio",
    "Disable video" : "Disable video",
    "Enable video" : "Enable video",
    "Screensharing options" : "Screensharing options",
    "Enable screensharing" : "Enable screensharing",
    "Screensharing requires the page to be loaded through HTTPS." : "Screensharing requires the page to be loaded through HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Sharing your screen only works with Firefox version 52 or newer.",
    "Screensharing extension is required to share your screen." : "Screensharing extension is required to share your screen.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Please use a different browser like Firefox or Chrome to share your screen.",
    "An error occurred while starting screensharing." : "An error occurred while starting screensharing.",
    "Back" : "Back",
    "You" : "You",
    "Show screen" : "Show screen",
    "Favorite" : "Favourite",
    "Leave conversation" : "Leave conversation",
    "Delete conversation" : "Delete conversation",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Save" : "Save",
    "Edit" : "Edit",
    "Password" : "Password",
    "API token" : "API token",
    "Login" : "Login",
    "Nickname" : "Nickname",
    "Client ID" : "Client ID",
    "Remove from favorites" : "Remove from favourites",
    "Add to favorites" : "Add to favourites",
    "Loading" : "Loading",
    "Groups" : "Groups",
    "Circles" : "Circles",
    "Password protect" : "Password protect",
    "Close" : "Close",
    "Conversation name" : "Conversation name",
    "Camera" : "Camera",
    "Reply" : "Reply",
    "Today" : "Today",
    "Yesterday" : "Yesterday",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Send message" : "Send message",
    "moderator" : "moderator",
    "guest" : "guest",
    "Demote from moderator" : "Demote from moderator",
    "Promote to moderator" : "Promote to moderator",
    "Remove participant" : "Remove participant",
    "No results" : "No results",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Participants",
    "Chat" : "Chat",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Search" : "Search",
    "Rename conversation" : "Rename conversation",
    "Grid view" : "Grid view",
    "Send" : "Send",
    "Start a conversation" : "Start a conversation",
    "Join a conversation or start a new one" : "Join a conversation or start a new one",
    "Default" : "Default",
    "Access to microphone & camera is only possible with HTTPS" : "Access to microphone & camera is only possible with HTTPS",
    "Please move your setup to HTTPS" : "Please move your setup to HTTPS",
    "Access to microphone & camera was denied" : "Access to microphone & camera was denied",
    "WebRTC is not supported in your browser" : "WebRTC is not supported in your browser",
    "Please use a different browser like Firefox or Chrome" : "Please use a different browser like Firefox or Chrome",
    "Error while accessing microphone & camera" : "Error while accessing microphone & camera",
    "The password is wrong. Try again." : "The password is wrong. Try again.",
    "TURN server" : "TURN server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "The TURN server is used to proxy the traffic from participants behind a firewall.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server.",
    "%s Talk on your mobile devices" : "%s Talk on your mobile devices",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "New in Talk 6" : "New in Talk 6",
    "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- One-to-one conversations are now persistent and can not be turned into group conversations by accident any more. Also when one of the participants leaves the conversation, the conversation is not automatically deleted any more. Only if both participants leave, the conversation is deleted from the server",
    "New in Talk 7" : "New in Talk 7",
    "New in Talk 8" : "New in Talk 8",
    "New in Talk 9" : "New in Talk 9",
    "{user} wants to talk with you" : "{user} wants to talk with you",
    "UDP and TCP" : "UDP and TCP",
    "UDP only" : "UDP only",
    "TCP only" : "TCP only",
    "Mute audio (m)" : "Mute audio (m)",
    "Unmute audio (m)" : "Unmute audio (m)",
    "Disable video (v)" : "Disable video (v)",
    "Enable video (v)" : "Enable video (v)",
    "Share link" : "Share link",
    "Exit fullscreen (f)" : "Exit fullscreen (f)",
    "Fullscreen (f)" : "Fullscreen (f)",
    "New in Talk 10" : "New in Talk 10",
    "Remove" : "Remove",
    "Enabled" : "Enabled"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A12.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/en_GB.js <==
OC.L10N.register(
    "spreed",
    {
    "a conversation" : "a conversation",
    "(Duration %s)" : "(Duration %s)",
    "You attended a call with {user1}" : "You attended a call with {user1}",
    "_%n guest_::_%n guests_" : ["%n guest","%n guests"],
    "You attended a call with {user1} and {user2}" : "You attended a call with {user1} and {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "You attended a call with {user1}, {user2} and {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "You attended a call with {user1}, {user2}, {user3} and {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}",
    "_%n other_::_%n others_" : ["%n other","%n others"],
    "{actor} invited you to {call}" : "{actor} invited you to {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>",
    "Talk" : "Talk",
    "Guest" : "Guest",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk.",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge and Safari can now be used to participate in audio and video calls",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- You can now notify all participants by posting \"@all\" into the chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- With the \"arrow-up\" key you can repost your last message",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some",
    "- With projects you can create quick links between conversations, files and other items" : "- With projects you can create quick links between conversations, files and other items",
    "- You can now mention guests in the chat" : "- You can now mention guests in the chat",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- You can now directly reply to messages giving the other users more context what your message is about",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- You can now add custom user groups to conversations when the circles app is installed",
    "- Check out the new grid and call view" : "- Check out the new grid and call view",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- You can now upload and drag'n'drop files directly from your device into the chat",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Shared files are now opened directly inside the chat view with the viewer apps",
    "- You can now search for chats and messages in the unified search in the top bar" : "- You can now search for chats and messages in the unified search in the top bar",
    "- Spice up your messages with emojis from the emoji picker" : "- Spice up your messages with emojis from the emoji picker",
    "- You can now change your camera and microphone while being in a call" : "- You can now change your camera and microphone while being in a call",
    "There are currently no commands available." : "There are currently no commands available.",
    "The command does not exist" : "The command does not exist",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "An error occurred while running the command. Please ask an administrator to check the logs.",
    "Talk updates ✅" : "Talk updates ✅",
    "{actor} created the conversation" : "{actor} created the conversation",
    "You created the conversation" : "You created the conversation",
    "An administrator created the conversation" : "An administrator created the conversation",
    "Talk to %s" : "Talk to %s",
    "{user} mentioned you in a private conversation" : "{user} mentioned you in a private conversation",
    "{user} invited you to a private conversation" : "{user} invited you to a private conversation",
    "Join call" : "Join call",
    "{user} invited you to a group conversation: {call}" : "{user} invited you to a group conversation: {call}",
    "A group call has started in {call}" : "A group call has started in {call}",
    "Open settings" : "Open settings",
    "Conversations" : "Conversations",
    "Messages" : "Messages",
    "Invalid date, date format must be YYYY-MM-DD" : "Invalid date, date format must be YYYY-MM-DD",
    "Leave call" : "Leave call",
    "This conversation has ended" : "This conversation has ended",
    "Limit to groups" : "Limit to groups",
    "Everyone" : "Everyone",
    "Save changes" : "Save changes",
    "Saved!" : "Saved!",
    "None" : "None",
    "User" : "User",
    "Disabled" : "Disabled",
    "Users" : "Users",
    "Beta" : "Beta",
    "Name" : "Name",
    "General settings" : "General settings",
    "Off" : "Off",
    "Language" : "Language",
    "Country" : "Country",
    "Status" : "Status",
    "Created at" : "Created at",
    "Pending" : "Pending",
    "Error" : "Error",
    "Blocked" : "Blocked",
    "Expired" : "Expired",
    "Shared secret" : "Shared secret",
    "Validate SSL certificate" : "Validate SSL certificate",
    "Saved" : "Saved",
    "STUN servers" : "STUN servers",
    "A STUN server is used to determine the public IP address of participants behind a router." : "A STUN server is used to determine the public IP address of participants behind a router.",
    "TURN server protocols" : "TURN server protocols",
    "Copy link" : "Copy link",
    "Waiting for others to join the call …" : "Waiting for others to join the call …",
    "You can invite others in the participant tab of the sidebar" : "You can invite others in the participant tab of the sidebar",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "You can invite others in the participant tab of the sidebar or share this link to invite others!",
    "Share this link to invite others!" : "Share this link to invite others!",
    "Show your screen" : "Show your screen",
    "Stop screensharing" : "Stop screensharing",
    "Settings" : "Settings",
    "Dismiss" : "Dismiss",
    "No audio" : "No audio",
    "Mute audio" : "Mute audio",
    "Disable video" : "Disable video",
    "Enable video" : "Enable video",
    "Screensharing options" : "Screensharing options",
    "Enable screensharing" : "Enable screensharing",
    "Screensharing requires the page to be loaded through HTTPS." : "Screensharing requires the page to be loaded through HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Sharing your screen only works with Firefox version 52 or newer.",
    "Screensharing extension is required to share your screen." : "Screensharing extension is required to share your screen.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Please use a different browser like Firefox or Chrome to share your screen.",
    "An error occurred while starting screensharing." : "An error occurred while starting screensharing.",
    "Back" : "Back",
    "You" : "You",
    "Show screen" : "Show screen",
    "Favorite" : "Favourite",
    "Leave conversation" : "Leave conversation",
    "Delete conversation" : "Delete conversation",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Save" : "Save",
    "Edit" : "Edit",
    "Password" : "Password",
    "API token" : "API token",
    "Login" : "Login",
    "Nickname" : "Nickname",
    "Client ID" : "Client ID",
    "Remove from favorites" : "Remove from favourites",
    "Add to favorites" : "Add to favourites",
    "Loading" : "Loading",
    "Groups" : "Groups",
    "Circles" : "Circles",
    "Password protect" : "Password protect",
    "Close" : "Close",
    "Conversation name" : "Conversation name",
    "Camera" : "Camera",
    "Reply" : "Reply",
    "Today" : "Today",
    "Yesterday" : "Yesterday",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Send message" : "Send message",
    "moderator" : "moderator",
    "guest" : "guest",
    "Demote from moderator" : "Demote from moderator",
    "Promote to moderator" : "Promote to moderator",
    "Remove participant" : "Remove participant",
    "No results" : "No results",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Participants",
    "Chat" : "Chat",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Search" : "Search",
    "Rename conversation" : "Rename conversation",
    "Grid view" : "Grid view",
    "Send" : "Send",
    "Start a conversation" : "Start a conversation",
    "Join a conversation or start a new one" : "Join a conversation or start a new one",
    "Default" : "Default",
    "Access to microphone & camera is only possible with HTTPS" : "Access to microphone & camera is only possible with HTTPS",
    "Please move your setup to HTTPS" : "Please move your setup to HTTPS",
    "Access to microphone & camera was denied" : "Access to microphone & camera was denied",
    "WebRTC is not supported in your browser" : "WebRTC is not supported in your browser",
    "Please use a different browser like Firefox or Chrome" : "Please use a different browser like Firefox or Chrome",
    "Error while accessing microphone & camera" : "Error while accessing microphone & camera",
    "The password is wrong. Try again." : "The password is wrong. Try again.",
    "TURN server" : "TURN server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "The TURN server is used to proxy the traffic from participants behind a firewall.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server.",
    "%s Talk on your mobile devices" : "%s Talk on your mobile devices",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "New in Talk 6" : "New in Talk 6",
    "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- One-to-one conversations are now persistent and can not be turned into group conversations by accident any more. Also when one of the participants leaves the conversation, the conversation is not automatically deleted any more. Only if both participants leave, the conversation is deleted from the server",
    "New in Talk 7" : "New in Talk 7",
    "New in Talk 8" : "New in Talk 8",
    "New in Talk 9" : "New in Talk 9",
    "New in Talk 10" : "New in Talk 10",
    "{user} wants to talk with you" : "{user} wants to talk with you",
    "UDP and TCP" : "UDP and TCP",
    "UDP only" : "UDP only",
    "TCP only" : "TCP only",
    "Mute audio (m)" : "Mute audio (m)",
    "Unmute audio (m)" : "Unmute audio (m)",
    "Disable video (v)" : "Disable video (v)",
    "Enable video (v)" : "Enable video (v)",
    "Remove" : "Remove",
    "Enabled" : "Enabled",
    "Share link" : "Share link",
    "Exit fullscreen (f)" : "Exit fullscreen (f)",
    "Fullscreen (f)" : "Fullscreen (f)"
},
"nplurals=2; plural=(n != 1);");
